@@ -1,5 +1,5 @@
 """
-Overall pipeline to train the model.  It parses arguments, and trains a CLSM model.
+Overall pipeline to train the model.  It parses arguments, and trains a DeText model.
 """
 
 import sys
@@ -30,6 +30,10 @@ def add_arguments(parser):
     parser.add_argument("--use_deep", type=str2bool, default=True, help="Whether to use deep features.")
     parser.add_argument("--elem_rescale", type=str2bool, default=True,
                         help="Whether to perform elementwise rescaling.")
+    parser.add_argument("--use_doc_projection", type=str2bool, default=False,
+                        help="whether to project multiple doc features to 1 vector.")
+    parser.add_argument("--use_usr_projection", type=str2bool, default=False,
+                        help="whether to project multiple usr features to 1 vector.")
 
     # Ranking specific
     parser.add_argument("--ltr_loss_fn", type=str, default='pairwise', help="learning-to-rank method.")
@@ -53,8 +57,8 @@ def add_arguments(parser):
     parser.add_argument("--bert_checkpoint", type=str, default=None, help="pretrained bert model checkpoint.")
 
     # LSTM related
-    parser.add_argument("--unit_type", type=str, default="lstm",
-                        help="RNN cell unit type. Support lstm/gru/layer_norm_lstm")
+    parser.add_argument("--unit_type", type=str, default="lstm", choices=["lstm"],
+                        help="RNN cell unit type. Currently only supports lstm. Will support other cell types in the future")
     parser.add_argument("--num_layers", type=int, default=1, help="RNN layers")
     parser.add_argument("--num_residual_layers", type=int, default=0,
                         help="Number of residual layers from top to bottom. For example, if `num_layers=4` and "
@@ -167,6 +171,8 @@ def create_hparams(flags):
         use_deep=flags.use_deep,
         elem_rescale=flags.elem_rescale,
         emb_sim_func=flags.emb_sim_func,
+        use_doc_projection=flags.use_doc_projection,
+        use_usr_projection=flags.use_usr_projection,
         num_classes=flags.num_classes,
         optimizer=flags.optimizer,
         max_gradient_norm=flags.max_gradient_norm,
